@@ -34,7 +34,7 @@ public:
 
 private:
     DB();
-    static bool createTables();
+    static bool createTables(bool update);
     static QSqlDatabase db_;
     static bool initialized_;
 };
