@@ -129,11 +129,20 @@ bool Settings::set(QString const& name, QString const& value)
         endEdit();
     }
 
+    settings_[name] = value;
+
     return returnValue;
 }
 
 QString Settings::get(QString const& name)
 {
+    QMap<QString, QString>::iterator it;
+
+    if((it = settings_.find(name)) != settings_.end())
+    {
+        return it.value();
+    }
+
     QString result = "";
 
     bool close = !editing_;
@@ -159,6 +168,8 @@ QString Settings::get(QString const& name)
         endEdit();
     }
 
+    settings_[name] = result;
+
     return result;
 
 }
