@@ -194,6 +194,29 @@
         <translation>Danish</translation>
     </message>
 </context>
+<context>
+    <name>LogWindow</name>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="30"/>
+        <source>Incoming call log</source>
+        <translation>Anropslogg</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="31"/>
+        <source>Clear log</source>
+        <translation>Tøm Logg</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="64"/>
+        <source>There are currently no logged calls</source>
+        <translation>Det er ingen mottatte anrop</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="134"/>
+        <source>%1 (no search results)</source>
+        <translation>%1 (ble ikke funnet)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -218,6 +241,11 @@
         <source>Search</source>
         <translation>Søk</translation>
     </message>
+    <message>
+        <location filename="../../gui/mainwindow.cpp" line="76"/>
+        <source>Log</source>
+        <translation>Logg</translation>
+    </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="82"/>
         <source>Settings</source>
@@ -236,7 +264,7 @@
     <message>
         <location filename="../../gui/mainwindow.cpp" line="116"/>
         <source>Unable to stop daemon.</source>
-        <translation>Kan ikke stoppe Autosøk.</translation>
+        <translation>Kan ikke stoppe autosøk.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="127"/>
