@@ -111,8 +111,6 @@ void CallListener::end()
 
 void CallListener::search(Source::SearchDetails const& details)
 {
-    qDebug() << "Search called";
-
     if(currentCall_)
     {
         delete currentCall_;
@@ -150,8 +148,6 @@ void CallListener::search(Source::SearchDetails const& details)
 
         showDelayedResult(tr("Searching..."), BANNER_DELAY);
 
-        qDebug() << "Starting to search...";
-
         source_->search(details);
     }
 
@@ -161,12 +157,14 @@ void CallListener::requestFinished(QVector <Source::Result> const& results,
                                    Source::SearchDetails const& details,
                                    bool error)
 {
-    if(closeConnection_)
+    /*if(closeConnection_)
     {
         closeConnection_ = false;
         ConnectionManager cm;
         cm.disconnect(true);
-    }
+    }*/
+
+    qDebug() << "Request finished";
 
     // If box is not visible, the call must have been terminated already
     if(!initialized_ || !box_->isVisible() || !currentCall_)
@@ -403,6 +401,14 @@ void CallListener::searchClose()
     box_ = 0;
     label_ = 0;
 
+    if(closeConnection_)
+    {
+        QTimer::singleShot(500, this, SLOT(closeConnection()));
+    }
+}
+
+void CallListener::closeConnection()
+{
     if(closeConnection_)
     {
         closeConnection_ = false;
@@ -422,6 +428,7 @@ bool CallListener::handleConnection()
 
     if(cm.isConnected())
     {
+        cm.connect();
         closeConnection_ = false;
         return true;
     }
@@ -515,10 +522,11 @@ bool CallListener::handleConnection()
             return false;
         }
 
-        qDebug() << "Connecting to " << best.name;
+        qDebug() << "Connecting to " << best.name << " (" << best.id << ")";
 
         if(cm.connect(best.id))
         {
+            sleep(500);
             break;
         }
         else if(cm.error() == ConnectionManager::INVALID_IAP)
@@ -533,7 +541,8 @@ bool CallListener::handleConnection()
 
         if(retries < CONNECT_RETRIES)
         {
-            sendRetrySignal(best.id, initialized_);
+            sendRetrySignal(best.id, false);
+            sleep(WAIT_BETWEEN_RETRIES);
         }
 
     }
@@ -601,7 +610,7 @@ bool CallListener::is3g()
 
 void CallListener::sendRetrySignal(QString const& iap, bool retry)
 {
-    QDBusMessage msg = QDBusMessage::createSignal("/com/nokia/icd_ui",
+   QDBusMessage msg = QDBusMessage::createSignal("/com/nokia/icd_ui",
                                                   "com.nokia.icd_ui",
                                                   "retry");
 
