@@ -22,7 +22,7 @@
 #include "searchdialog.h"
 #include "resultwindow.h"
 #include "detailwindow.h"
-#include "eniro.h"
+#include "source.h"
 #include "settings.h"
 
 int main(int argc, char *argv[])
@@ -43,5 +43,8 @@ int main(int argc, char *argv[])
     QObject::connect(&results, SIGNAL(itemSelected(Source::Result const&)),
                      &details, SLOT(loadData(Source::Result const&)));
 
+    QObject::connect(&window, SIGNAL(logItemSelected(Source::Result const&)),
+                     &details, SLOT(loadData(Source::Result const&)));
+
     return app.exec();
 }
